#[repr(i32)]pub enum EAuthSessionSecurityHistory {
KEAuthSessionSecurityHistoryInvalid = 0,
KEAuthSessionSecurityHistoryUsedPreviously = 1,
KEAuthSessionSecurityHistoryNoPriorHistory = 2,
}Expand description
Security history for authentication sessions
Variants
KEAuthSessionSecurityHistoryInvalid = 0
KEAuthSessionSecurityHistoryUsedPreviously = 1
KEAuthSessionSecurityHistoryNoPriorHistory = 2
Implementations
Sourceimpl EAuthSessionSecurityHistory
impl EAuthSessionSecurityHistory
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of EAuthSessionSecurityHistory.
Sourcepub fn from_i32(value: i32) -> Option<EAuthSessionSecurityHistory>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EAuthSessionSecurityHistory>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EAuthSessionSecurityHistory, or None if value is not a valid variant.