#[repr(i32)]pub enum EAuthTokenPlatformType {
KEAuthTokenPlatformTypeUnknown = 0,
KEAuthTokenPlatformTypeSteamClient = 1,
KEAuthTokenPlatformTypeWebBrowser = 2,
KEAuthTokenPlatformTypeMobileApp = 3,
}Expand description
Platform type for authentication tokens
Variants
KEAuthTokenPlatformTypeUnknown = 0
KEAuthTokenPlatformTypeSteamClient = 1
KEAuthTokenPlatformTypeWebBrowser = 2
KEAuthTokenPlatformTypeMobileApp = 3
Implementations
Sourceimpl EAuthTokenPlatformType
impl EAuthTokenPlatformType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of EAuthTokenPlatformType.
Sourcepub fn from_i32(value: i32) -> Option<EAuthTokenPlatformType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EAuthTokenPlatformType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EAuthTokenPlatformType, or None if value is not a valid variant.