pub async fn execute_single_transfer(
http_client: &HttpClient,
transfer: &TransferInfo,
steam_id: u64,
) -> TransferResultExpand description
Execute a single transfer request and extract cookies from the response.
pub async fn execute_single_transfer(
http_client: &HttpClient,
transfer: &TransferInfo,
steam_id: u64,
) -> TransferResultExecute a single transfer request and extract cookies from the response.